@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008001;
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 use Carp ();
 use URI ();
@@ -216,7 +216,7 @@ sub _get_args {
     my $data;
     for my $line (split "\n", $content) {
         next unless $line;
-        if ($line =~ /^\s*yt\.playerConfig\s*=\s*({.*})/) {
+        if ($line =~ /^.+ytplayer\.config\s*=\s*({.*})/) {
             $data = JSON->new->utf8(1)->decode($1);
             last;
         }
